@@ -4,20 +4,11 @@ use thiserror::Error;
 pub enum MyError {
     #[error("Git repo does not exist.")]
     GitRepoDoesNotExist,
-    #[error("bad path")]
-    BadPath,
-    #[error("unknown file path")]
-    UnknownFilePath,
     #[error("io error")]
     Io {
         #[from]
         source: std::io::Error,
     },
-    #[error("http error")]
-    Http {
-        #[from]
-        source: hyper::http::Error,
-    },
     #[error("template error")]
     TemplateError {
         #[from]
